==> bcc-core-api-node-sdk-1.7.2.tgz: package/lib/esm/api/orgsClient.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { GenericClient } from "./genericClient";
export class OrgsClient {
    constructor(basePath, auth) {
        this.client = new GenericClient({
            basePath: basePath,
            endpointPath: "/v2/orgs",
            auth: auth,
            writeTypeName: "OrgWrite",
            singleResponseTypeName: "WrappedOrg",
            multipleResponseTypeName: "WrappedWithMetaArrayOrg",
            patchTypeName: "OrgWrite",
        });
    }
    create(org) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.create(org);
        });
    }
    get(id, query = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.get(id, query);
        });
    }
    find(findParams = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.find(findParams);
        });
    }
    patch(id, org) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.patch(id, org);
        });
    }
}

==> bcc-core-api-node-sdk-1.10.0.tgz: package/lib/esm/api/orgsClient.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { GenericClient } from "./genericClient.js";
export class OrgsClient {
    constructor(basePath, auth) {
        this.client = new GenericClient({
            basePath: basePath,
            endpointPath: "/v2/orgs",
            auth: auth,
            writeTypeName: "OrgWrite",
            singleResponseTypeName: "WrappedOrg",
            multipleResponseTypeName: "WrappedWithMetaArrayOrg",
            patchTypeName: "OrgWrite",
        });
    }
    create(org) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.create(org);
        });
    }
    get(id, query = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.get(id, query);
        });
    }
    find(findParams = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.find(findParams);
        });
    }
    patch(id, org) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.patch(id, org);
        });
    }
}
